<?php
/**
 * Foursquare Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Foursquare stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdminfoursquareFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed id
	 *
	 * @var int
	 */
	public $feed_id = '';
	/**
	 * Next URL
	 *
	 * @var int
	 */
	public $next_url = 1;
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get feed Detail.
	 *
	 * @since  1.0.0
	 * @return string
	 */
	public function ssd_get_foursquare_stream_from_feed() {
		$feed_detail          = $this->feed_detail;
		$location_id          = $feed_detail['ssd_feed_type_foursquare_location_id'];
		$foursquare_feed_type = $feed_detail['ssd_feed_type_foursquare_feed_type'];
		$feed_limit           = $feed_detail['feed_limit'];
		$foursquare_stream    = get_option( 'foursquare_stream' );
		$access_token         = $foursquare_stream['foursquare_access_token'];
		if ( '' == $access_token ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Authentication Missing. Please Check Authentication Setting', 'social-stream-designer' ) );
		}
		if ( '' == $location_id ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Location ID' ) );
		}
		$today_date = gmdate( 'Ymd' );
		if ( 'photos' === $foursquare_feed_type ) {
			$feedtype = 'photos';
		} else {
			$feedtype = 'tips';
		}
		$url = 'https://api.foursquare.com/v2/venues/' . $location_id . '/' . $feedtype . '?oauth_token=' . $access_token . '&v=' . $today_date;

		$read_feeds = Social_Stream_Main::ssd_get_data_from_remote_url( $url );

		$get_feeds = json_decode( $read_feeds );

		if ( isset( $get_feeds->meta->errorDetail ) ) {
			$message = $get_feeds->meta->errorDetail . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		$data = '';
		if ( 'photos' === $foursquare_feed_type ) {
			if ( isset( $get_feeds->response->photos->items ) ) {
				$data = $get_feeds->response->photos->items;
			}
		} else {
			if ( isset( $get_feeds->response->tips->items ) ) {
				$data = $get_feeds->response->tips->items;
			}
		}
		$get_php_error = Social_Stream_Main::ssd_get_last_error();
		if ( $get_php_error ) {
			$message = $get_php_error['message'] . '!!!! ' . esc_html__( 'Please try again', 'social-stream-designer' );
			return new WP_Error( 'ssd-feeds-errors', $message );
		}
		if ( ! empty( $data ) ) {
			foreach ( $data as $item ) {
				$photo_url = '';
				$tips      = '';
				if ( isset( $item->photourl ) ) {
					$photo_url = $item->photourl;
					$tips      = 'image';
				}
				$created_date                       = $item->createdAt;
				$feeds['feed_id']                   = $this->feed_id;
				$feeds['unique_id']                 = $item->id;
				$feeds['post_comment_id']       	= $item->id;
				$feeds['feed_type']                 = 'foursquare';
				$feeds['post_title']                = '';
				$feeds['post_description']          = $item->text;
				$feeds['post_date']                 = gmdate( 'Y-m-d H:i:s', $created_date );
				$feeds['post_link']                 = $item->canonicalUrl;
				$feeds['post_language']             = '';
				$feeds['post_user_name']            = $item->user->firstName;
				$feeds['post_user_screen_name']     = $item->user->firstName;
				$feeds['post_user_location']        = '';
				$feeds['post_user_description']     = '';
				$feeds['post_user_link']            = 'https://foursquare.com/user/' . $item->user->id;
				$feeds['post_user_image']           = $item->user->photo->prefix . '64x64' . $item->user->photo->suffix;
				$feeds['post_user_followers_count'] = '';
				$feeds['post_user_friends_count']   = '';
				$feeds['post_retweet_count']        = '';
				$feeds['post_favorite_count']       = $item->agreeCount;
				$feeds['post_comment_count']        = '';
				$feeds['post_plays_count']          = isset( $item->viewCount ) ? $item->viewCount : '';
				$feeds['post_likes_count']          = $item->likes->count;
				$feeds['post_dislikes_count']       = $item->disagreeCount;
				$feeds['reply_to_link']             = '';
				$feeds['retweet_link']              = '';
				$feeds['favourite_link']            = $item->canonicalUrl;
				$feeds['like_link']                 = $item->canonicalUrl;
				$feeds['play_link']                 = $item->canonicalUrl;
				$feeds['type_in']                   = $tips;
				$feeds['post_image']                = $photo_url;
				$feeds['post_video']                = '';
				$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
				if ( $this->ssd_feed_limit_count <= $feed_limit ) {
					$this->post_feeds[] = $feeds;
				}
			}
		}
	}
}
