<?php
/**
 * Vimeo Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Vimeo stream data
 *
 * @return array
 */
class SSDAdminvimeoFeeds {

	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';

	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';

	/**
	 * Feed Detail
	 *
	 * @var string
	 */
	public $feed_detail = '';

	/**
	 * Feed ID
	 *
	 * @var int
	 */
	public $feed_id = '';

	/**
	 * Page
	 *
	 * @var int
	 */
	public $page = 1;

	/**
	 * Main Page
	 *
	 * @var int
	 */
	public $main_page = 1;

	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();

	/**
	 * Pagination URL
	 *
	 * @var string
	 */
	public $pagination_url = '';

	/**
	 * Vimeo Feeds
	 *
	 * @var array
	 */
	public $vimeo_feeds = array();

	/**
	 * Count Feed Limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';

	/**
	 * Initial Setup
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}

	/**
	 * Get feed type from feed id.
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}

	/**
	 * Get all feed details.
	 */
	public function ssd_get_vimeo_stream_from_feed() {
		$feed_detail       = $this->feed_detail;
		$feed_type_vimeo   = $feed_detail['feed_type_vimeo'];
		$feed_limit        = $feed_detail['feed_limit'];
		$vimeo_stream      = get_option( 'vimeo_stream' );
		$vimeo_client_id   = $vimeo_stream['client_id'] ? $vimeo_stream['client_id'] : '';
		$vimeo_secrets_key = $vimeo_stream['secrets_key'] ? $vimeo_stream['secrets_key'] : '';

		if ( '' == $vimeo_client_id || '' == $vimeo_secrets_key ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Authentication Missing. Please Check Authentication Setting', 'social-stream-designer' ) );
		}

		include_once SOCIALSTREAMDESIGNER_DIR . 'include/vimeoPhp/autoload.php';
		$lib   = new \Vimeo\Vimeo( $vimeo_client_id, $vimeo_secrets_key );
		$token = $lib->clientCredentials( array( 'private', 'public', 'purchased', 'create', 'edit', 'delete', 'interact', 'upload', 'video_files' ) );
		if ( isset( $token['body']['access_token'] ) && '' !== $token['body']['access_token'] ) {
			$lib->setToken( $token['body']['access_token'] );
		}

		if ( ! isset( $token['body']['access_token'] ) ) {
			return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please Re-enter Client ID and Secret Key', 'social-stream-designer' ) );
		}
		if ( $feed_limit < 100 ) {
			$per_page = $feed_limit;
		} else {
			$per_page = 100;
		}
		if ( 'group' === $feed_type_vimeo || 'channel' === $feed_type_vimeo || 'album' === $feed_type_vimeo ) {
			if ( '' == $this->pagination_url ) {
				if ( 'channel' === $feed_type_vimeo ) {
					$channel_id = $feed_detail['ssd_feed_type_vimeo_channelid'];
					if ( '' == $channel_id ) {
						return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Channel ID' ) );
					}
					$response = $lib->request( '/channels/' . $channel_id . '/videos?per_page=' . $per_page, '', 'GET' );
				} elseif ( 'album' === $feed_type_vimeo ) {
					$album_id      = $feed_detail['ssd_feed_type_vimeo_albumid'];
					$vimeo_user_id = $feed_detail['ssd_feed_type_vimeo_userid'];
					if ( '' == $album_id || '' == $vimeo_user_id ) {
						return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Album ID And User ID' ) );
					}
					$response = $lib->request( '/users/' . $vimeo_user_id . '/albums/' . $album_id . '/videos?per_page=' . $per_page, '', 'GET' );
				} else {
					$group_id = $feed_detail['ssd_feed_type_vimeo_groupid'];
					if ( '' == $group_id ) {
						return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' Group ID' ) );
					}
					$response = $lib->request( '/groups/' . $group_id . '/videos?per_page=' . $per_page, '', 'GET' );
				}
			} else {
				$response = $lib->request( $this->pagination_url, '', 'GET' );
			}

			if ( isset( $response['body']['paging']['next'] ) && null !== $response['body']['paging']['next'] ) {
				$this->pagination_url = $response['body']['paging']['next'];
			} else {
				$this->pagination_url = '';
			}

			$data = isset( $response['body']['data'] ) ? $response['body']['data'] : '';
			if ( '' !== $data ) {
				foreach ( $data as $item ) {
					$video_id                       = explode( '/', $item['link'] );
					$feeds['unique_id']             = $video_id[3];
					$feeds['post_comment_id']       = $video_id[3];
					$feeds['post_title']            = $item['name'];
					$feeds['post_description']      = ( null !== $item['description'] ) ? $item['description'] : '';
					$feeds['post_date']             = $item['created_time'];
					$feeds['post_link']             = $item['link'];
					$feeds['post_image']            = $item['pictures']['sizes'][0]['link'];
					$feeds['url']                   = $item['link'];
					$feeds['post_user_image']       = $item['user']['pictures']['sizes'][1]['link'];
					$feeds['post_user_name']        = $item['user']['name'];
					$feeds['post_user_screen_name'] = $item['name'];
					$feeds['post_user_link']        = $item['user']['link'];
					$feeds['post_comment_count']    = Social_Stream_Main::ssd_formatwithsuffix( $item['metadata']['connections']['comments']['total'] );
					$feeds['post_plays_count']      = Social_Stream_Main::ssd_formatwithsuffix( $item['stats']['plays'] );
					$feeds['post_likes_count']      = Social_Stream_Main::ssd_formatwithsuffix( $item['metadata']['connections']['likes']['total'] );
					$feeds['type_in']               = 'video';
					if ( 'album' === $feed_type_vimeo ) {
						$feeds['post_video'] = 'https://player.vimeo.com/video/' . $video_id[3];
					} else {
						$feeds['post_video'] = 'https://player.vimeo.com/video/' . $video_id[3];
					}
					$this->ssd_feed_limit_count = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->vimeo_feeds[] = $feeds;
					}
				}
			}

			if ( '' !== $this->pagination_url && $this->ssd_feed_limit_count <= $feed_limit ) {
				$this->page = $this->page + 1;
				$this->ssd_get_vimeo_stream_from_feed();
			}
		} elseif ( 'user_videos' === $feed_type_vimeo || 'liked_videos' === $feed_type_vimeo ) {
			$vimeo_user_id = $feed_detail['ssd_feed_type_vimeo_userid'];
			if ( '' == $vimeo_user_id ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Please enter', 'social-stream-designer' ) . esc_html( ' User ID' ) );
			}

			if ( 'user_videos' === $feed_type_vimeo ) {
				$page     = $this->page;
				$response = $lib->request( '/users/' . $vimeo_user_id . '/videos?per_page=' . $per_page . '&page=' . $page, '', 'GET' );
			} elseif ( 'liked_videos' === $feed_type_vimeo ) {
				$page = $this->page;

				$response = $lib->request( '/users/' . $vimeo_user_id . '/likes?per_page=' . $per_page . '&page=' . $page, '', 'GET' );
			}
			if ( null !== $response['body']['paging']['next'] ) {
				$pagination = 'yes';
			} else {
				$pagination = 'no';
			}
			$data_items = $response['body']['data'];
			if ( ! empty( $data_items ) ) {
				foreach ( $data_items as $item ) {
					$video_id                       = explode( '/', $item['link'] );
					$feeds['unique_id']             = $video_id[3];
					$feeds['post_comment_id']       = $video_id[3];
					$feeds['post_title']            = $item['name'];
					$feeds['post_description']      = ( null !== $item['description'] ) ? $item['description'] : '';
					$feeds['post_date']             = human_time_diff( strtotime( $item['created_time'] ), current_time( 'timestamp' ) ) . ' ago';
					$feeds['post_link']             = $item['link'];
					$feeds['post_image']            = $item['pictures']['sizes'][0]['link'];
					$feeds['url']                   = $item['link'];
					$feeds['post_user_image']       = $item['user']['pictures']['sizes'][1]['link'];
					$feeds['post_user_name']        = $item['user']['name'];
					$feeds['post_user_screen_name'] = $item['name'];
					$feeds['post_user_link']        = $item['user']['link'];
					$feeds['post_comment_count']    = Social_Stream_Main::ssd_formatwithsuffix( $item['metadata']['connections']['comments']['total'] );
					$feeds['post_plays_count']      = Social_Stream_Main::ssd_formatwithsuffix( $item['stats']['plays'] );
					$feeds['post_likes_count']      = Social_Stream_Main::ssd_formatwithsuffix( $item['metadata']['connections']['likes']['total'] );
					$feeds['type_in']               = 'video';
					$feeds['post_video']            = 'https://player.vimeo.com/video/' . $video_id[3];
					$this->ssd_feed_limit_count     = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->vimeo_feeds[] = $feeds;
					}
				}
			}
			if ( 'yes' === $pagination && $this->ssd_feed_limit_count <= $feed_limit ) {
				$this->page = $this->page + 1;
				$this->ssd_get_vimeo_stream_from_feed();
			}
		}

		$vimeo_feeds_new = array();
		$vimeo_feed_data = $this->vimeo_feeds;
		if ( ! empty( $vimeo_feed_data ) ) {
			foreach ( $vimeo_feed_data as $vimeo_feed ) {
				$vimeo_feed['feed_id']                   = $this->feed_id;
				$vimeo_feed['feed_type']                 = 'vimeo';
				$vimeo_feed['type_in']                   = 'video';
				$vimeo_feed['reply_to_link']             = '';
				$vimeo_feed['retweet_link']              = '';
				$vimeo_feed['post_retweet_count']        = '';
				$vimeo_feed['favourite_link']            = '';
				$vimeo_feed['like_link']                 = '';
				$vimeo_feed['play_link']                 = '';
				$vimeo_feed['posttype']                  = '';
				$vimeo_feed['carousel_media']            = '';
				$vimeo_feed['message_2']                 = '';
				$vimeo_feed['post_language']             = '';
				$vimeo_feed['post_user_location']        = '';
				$vimeo_feed['post_user_description']     = '';
				$vimeo_feed['post_user_followers_count'] = '';
				$vimeo_feed['post_user_friends_count']   = '';
				$vimeo_feed['post_dislikes_count']       = '';
				$vimeo_feed['post_favorite_count']       = '';
				$vimeo_feed['feed_type']                 = 'vimeo';
				$vimeo_feeds_new[]                       = $vimeo_feed;
			}
		}

		$this->post_feeds = $vimeo_feeds_new;

	}

}
