<?php
/**
 * WordPress Social media class file get all social feed
 *
 * @version 1.0
 * @package WP Social Stream Designer PRO
 */

/**
 * Get Vimeo stream data
 *
 * @package    Social Stream Designer
 * @subpackage Social Stream Designer/admin/assets/feeds
 * @author     Solwin Infotech <support@solwininfotech.com>
 */
class SSDAdminwordpressFeeds {
	/**
	 * Table name
	 *
	 * @var string
	 */
	public $feed_posts_table = '';
	/**
	 * Feed Object
	 *
	 * @var string
	 */
	public $feeds_object = '';
	/**
	 * Feed Details
	 *
	 * @var string
	 */
	public $feed_detail = '';
	/**
	 * Feed ID
	 *
	 * @var string
	 */
	public $feed_id = '';
	/**
	 * Next URL
	 *
	 * @var int
	 */
	public $next_url = 1;
	/**
	 * Post Feeds
	 *
	 * @var array
	 */
	public $post_feeds = array();
	/**
	 * Count Feed Limit
	 *
	 * @var int
	 */
	public $ssd_feed_limit_count = '0';
	/**
	 * Initial Setup
	 *
	 * @since  1.0.0
	 * @return void
	 */
	public function init() {
		global $wpdb;
		$this->feed_posts_table = $wpdb->prefix . 'ssd_feed_posts';
		if ( isset( $_POST['feed_stream_nonce'] ) ) {
			if ( isset( $_POST['feed_stream_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['feed_stream_nonce'] ) ), 'social-stream-designer_meta_box_nonce' ) ) {
				if ( isset( $_REQUEST['action'] ) && 'edit' === $_REQUEST['action'] && isset( $_REQUEST['id'] ) && '' != $_REQUEST['id'] ) {
					$this->feed_id = sanitize_text_field( wp_unslash( $_REQUEST['id'] ) );
				}
			}
		}
		$feed_detail       = $this->ssd_get_feed_detail();
		$this->feed_detail = $feed_detail;
	}
	/**
	 * Get feed type from feed id.
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_feed_detail() {
		global $wpdb;
		$feed_id      = $this->feed_id;
		$result_feeds = $wpdb->get_row( $wpdb->prepare( "select * from $wpdb->prefix" . 'ssd_feeds where id = %d', $feed_id ) );
		if ( $result_feeds ) {
			$feeds_settings  = $result_feeds->feeds_settings;
			$feeds_settings  = maybe_unserialize( $feeds_settings );
			$this->feed_type = $feeds_settings['feed'];
			return $feeds_settings;
		} else {
			return '';
		}
	}
	/**
	 * Get WordPress post
	 *
	 * @param string $category WordPress post category.
	 * @param string $feed_limit feed limit.
	 * @return array
	 */
	public function ssd_get_wordpress_posts( $category, $feed_limit ) {
		global $wpdb;
		$args     = array(
			'category_name' => $category,
			'numberposts'   => $feed_limit,
		);
		$wp_posts = get_posts( $args );
		return $wp_posts;
	}
	/**
	 * Get WordPress Custom post type
	 *
	 * @param string $feed_limit feed limit.
	 * @param string $post_type Custom post type.
	 * @return array
	 */
	public function ssd_get_wordpress_custom_posts( $feed_limit, $post_type ) {
		global $wpdb;
		$args     = array(
			'category_name' => $category,
			'numberposts'   => $feed_limit,
			'post_type'     => $post_type,
		);
		$wp_posts = get_posts( $args );
		return $wp_posts;
	}
	/**
	 * Get WordPress Comments.
	 *
	 * @param string $post_id WordPress post id.
	 * @return array
	 */
	public function ssd_get_wordpress_comments( $post_id ) {
		global $wpdb;
		$get_post = get_post_status( $post_id );
		if ( isset( $get_post ) && '' !== $get_post ) {
			$args        = array( 'post_id' => $post_id );
			$wp_comments = get_comments( $args );
			return $wp_comments;
		} else {
			$wp_comments = get_comments();
			return $wp_comments;
		}
	}
	/**
	 * Get feed Detail
	 *
	 * @since  1.0.0
	 * @return array
	 */
	public function ssd_get_wordpress_stream_from_feed() {
		$feed_detail         = $this->feed_detail;
		$feed_type_wordpress = $feed_detail['feed_type_wordpress'];
		$feed_limit          = $feed_detail['feed_limit'];
		if ( '' !== $feed_detail['ssd_feed_type_wp_cat_name'] ) {
			$category = $feed_detail['ssd_feed_type_wp_cat_name'];
		} else {
			$category = '';
		}
		if ( 'posts' === $feed_type_wordpress ) {
			$get_feeds = $this->ssd_get_wordpress_posts( $category, $feed_limit );

			if ( ! empty( $get_feeds ) ) {

				foreach ( $get_feeds as $item ) {
					global $wpdb;
					if ( has_post_thumbnail( $item->ID ) ) {
						$image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $item->ID ), 'full' );
						$image       = $image_array[0];
					} else {
						$image = '';
					}

					$authid                             = $item->post_author;
					$authername                         = get_the_author_meta( 'display_name', $authid );
					$user_description                   = get_the_author_meta( 'user_description', $authid );
					$user_image                         = get_avatar_url( $authid );
					$created_date                       = $item->post_date;
					$feeds['feed_id']                   = $this->feed_id;
					$feeds['unique_id']                 = $item->ID;
					$feeds['post_comment_id']      		= '';
					$feeds['feed_type']                 = 'WordPress';
					$feeds['post_title']                = $item->post_title;
					$feeds['post_description']          = $item->post_content;
					$feeds['post_date']                 = $created_date;
					$feeds['post_link']                 = $item->guid;
					$feeds['post_language']             = '';
					$feeds['post_user_name']            = $authername;
					$feeds['post_user_screen_name']     = $authername;
					$feeds['post_user_location']        = '';
					$feeds['post_user_description']     = $user_description;
					$feeds['post_user_link']            = $item->guid;
					$feeds['post_user_image']           = $user_image;
					$feeds['post_user_followers_count'] = '';
					$feeds['post_user_friends_count']   = '';
					$feeds['post_retweet_count']        = '';
					$feeds['post_favorite_count']       = '';
					$feeds['post_comment_count']        = $item->comment_count;
					$feeds['post_plays_count']          = '0';
					$feeds['post_likes_count']          = '';
					$feeds['post_dislikes_count']       = '0';
					$feeds['reply_to_link']             = '';
					$feeds['retweet_link']              = '';
					$feeds['favourite_link']            = '';
					$feeds['like_link']                 = '';
					$feeds['play_link']                 = '';
					$feeds['type_in']                   = 'image';
					$feeds['post_image']                = $image;
					$feeds['post_video']                = '';
					$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->post_feeds[] = $feeds;
					}
				}
			}
		} elseif ( 'comments' === $feed_type_wordpress ) {
			if ( '' !== $feed_detail['ssd_feed_type_wp_post_id'] ) {
				$post_id = $feed_detail['ssd_feed_type_wp_post_id'];
			} else {
				$post_id = '';
			}

			$get_feeds = $this->ssd_get_wordpress_comments( $post_id );
			if ( false == $get_feeds ) {
				return new WP_Error( 'ssd-feeds-errors', esc_html__( 'Not found post ID!!!! Please try again.', 'social-stream-designer' ) );
			}
			if ( ! empty( $get_feeds ) ) {
				foreach ( $get_feeds as $item ) {
					$created_date                       = $item->comment_date;
					$feeds['feed_id']                   = $this->feed_id;
					$feeds['unique_id']                 = $item->comment_ID;
					$feeds['post_comment_id']      		= '';
					$feeds['feed_type']                 = 'WordPress';
					$feeds['post_title']                = '';
					$feeds['post_description']          = $item->comment_content;
					$feeds['post_date']                 = $created_date;
					$feeds['post_link']                 = '';
					$feeds['post_language']             = '';
					$feeds['post_user_name']            = $item->comment_author;
					$feeds['post_user_screen_name']     = $item->comment_author;
					$feeds['post_user_location']        = '';
					$feeds['post_user_description']     = '';
					$feeds['post_user_link']            = '';
					$feeds['post_user_image']           = '';
					$feeds['post_user_followers_count'] = '';
					$feeds['post_user_friends_count']   = '';
					$feeds['post_retweet_count']        = '';
					$feeds['post_favorite_count']       = '';
					$feeds['post_comment_count']        = '';
					$feeds['post_plays_count']          = '0';
					$feeds['post_likes_count']          = '';
					$feeds['post_dislikes_count']       = '0';
					$feeds['reply_to_link']             = '';
					$feeds['retweet_link']              = '';
					$feeds['favourite_link']            = '';
					$feeds['like_link']                 = '';
					$feeds['play_link']                 = '';
					$feeds['type_in']                   = 'comments';
					$feeds['post_image']                = '';
					$feeds['post_video']                = '';
					$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->post_feeds[] = $feeds;
					}
				}
			}
		} else {
			$get_feeds = $this->ssd_get_wordpress_custom_posts( $feed_limit, $feed_type_wordpress );

			if ( ! empty( $get_feeds ) ) {

				foreach ( $get_feeds as $item ) {
					global $wpdb;
					if ( has_post_thumbnail( $item->ID ) ) {
						$image_array = wp_get_attachment_image_src( get_post_thumbnail_id( $item->ID ), 'full' );
						$image       = $image_array[0];
					} else {
						$image = '';
					}

					$authid                             = $item->post_author;
					$authername                         = get_the_author_meta( 'display_name', $authid );
					$user_description                   = get_the_author_meta( 'user_description', $authid );
					$user_image                         = get_avatar_url( $authid );
					$created_date                       = $item->post_date;
					$feeds['feed_id']                   = $this->feed_id;
					$feeds['unique_id']                 = $item->ID;
					$feeds['post_comment_id']      		= '';
					$feeds['feed_type']                 = 'WordPress';
					$feeds['post_title']                = $item->post_title;
					$feeds['post_description']          = $item->post_content;
					$feeds['post_date']                 = $created_date;
					$feeds['post_link']                 = $item->guid;
					$feeds['post_language']             = '';
					$feeds['post_user_name']            = $authername;
					$feeds['post_user_screen_name']     = $authername;
					$feeds['post_user_location']        = '';
					$feeds['post_user_description']     = $user_description;
					$feeds['post_user_link']            = $item->guid;
					$feeds['post_user_image']           = $user_image;
					$feeds['post_user_followers_count'] = '';
					$feeds['post_user_friends_count']   = '';
					$feeds['post_retweet_count']        = '';
					$feeds['post_favorite_count']       = '';
					$feeds['post_comment_count']        = $item->comment_count;
					$feeds['post_plays_count']          = '0';
					$feeds['post_likes_count']          = '';
					$feeds['post_dislikes_count']       = '0';
					$feeds['reply_to_link']             = '';
					$feeds['retweet_link']              = '';
					$feeds['favourite_link']            = '';
					$feeds['like_link']                 = '';
					$feeds['play_link']                 = '';
					$feeds['type_in']                   = 'image';
					$feeds['post_image']                = $image;
					$feeds['post_video']                = '';
					$this->ssd_feed_limit_count         = $this->ssd_feed_limit_count + 1;
					if ( $this->ssd_feed_limit_count <= $feed_limit ) {
						$this->post_feeds[] = $feeds;
					}
				}
			}
		}
	}
}
